@@ -148,7 +148,8 @@ cranDownloads <- function(packages = NULL, when = NULL, from = NULL,
 #' @param population.seed Numeric. Seed for sample in population plot.
 #' @param multi.plot Logical.
 #' @param same.xy Logical. Use same scale for multiple packages when graphics = "base".
-#' @param legend.loc Character.
+#' @param legend.location Character.
+#' @param ip.legend.location Character. Location of in-progress legend.
 #' @param r.total Logical.
 #' @param dev.mode Logical. Use packageHistory0() to scrape CRAN.
 #' @param unit.observation Character. "year", "month", or "day".
@@ -168,8 +169,9 @@ plot.cranDownloads <- function(x, statistic = "count", graphics = "auto",
   points = "auto", log.count = FALSE, smooth = FALSE, se = FALSE, f = 1/3,
   span = 3/4, package.version = FALSE, r.version = FALSE,
   population.plot = FALSE, population.seed = as.numeric(Sys.Date()),
-  multi.plot = FALSE, same.xy = TRUE, legend.loc = "topleft", r.total = FALSE,
-  dev.mode = FALSE, unit.observation = "day", multi.core = TRUE, ...) {
+  multi.plot = FALSE, same.xy = TRUE, legend.location = "topleft",
+  ip.legend.location = "topright", r.total = FALSE, dev.mode = FALSE,
+  unit.observation = "day", multi.core = TRUE, ...) {
 
   cores <- multiCore(multi.core)
 
@@ -220,19 +222,20 @@ plot.cranDownloads <- function(x, statistic = "count", graphics = "auto",
        population.seed = population.seed)
   } else if ("R" %in% x$packages) {
     if (r.total) {
-      rTotPlot(x, statistic, graphics, legend.loc, points, log.count, smooth,
-        se, r.version, f, span)
+      rTotPlot(x, statistic, graphics, legend.location, points, log.count,
+        smooth, se, r.version, f, span)
     } else {
-      rPlot(x, statistic, graphics, obs.ct, legend.loc, points, log.count,
-        smooth, se, r.version, f, span, multi.plot)
+      rPlot(x, statistic, graphics, obs.ct, legend.location,
+        ip.legend.location, points, log.count, smooth, se, r.version, f, span,
+        multi.plot)
     }
   } else if (is.null(x$packages)) {
     cranPlot(x, statistic, graphics, points, log.count, smooth, se, f, span,
       r.version)
   } else {
     if (multi.plot) {
-      multiPlot(x, statistic, graphics, obs.ct, log.count, legend.loc,
-        points, smooth, se, f, span)
+      multiPlot(x, statistic, graphics, obs.ct, log.count, legend.location,
+        ip.legend.location, points, smooth, se, f, span)
     } else {
       singlePlot(x, statistic, graphics, obs.ct, points, smooth, se, f,
         span, log.count, package.version, dev.mode, r.version, same.xy)
