@@ -5,13 +5,12 @@
 #' @param date Character. Date. "yyyy-mm-dd". NULL uses latest available log.
 #' @param all.filters Logical. Master switch for filters.
 #' @param ip.filter Logical.
-#' @param triplet.filter Logical.
 #' @param small.filter Logical. TRUE filters out downloads less than 1000 bytes.
-#' @param sequence.filter Logical.
-#' @param size.filter Logical.
 #' @param memoization Logical. Use memoization when downloading logs.
 #' @param check.package Logical. Validate and "spell check" package.
 #' @param multi.core Logical or Numeric. \code{TRUE} uses \code{parallel::detectCores()}. \code{FALSE} uses one, single core. You can also specify the number logical cores. Mac and Unix only.
+#' @param dev.mode Logical. Development mode uses parallel::parLapply().
+#' @param threshold Numeric. Threshold for small.filter in Bytes.
 #' @return An R data frame.
 #' @export
 #' @examples
@@ -21,70 +20,40 @@
 #' }
 
 packageRank <- function(packages = "HistData", date = NULL,
-  all.filters = FALSE, ip.filter = FALSE, triplet.filter = FALSE,
-  small.filter = FALSE, sequence.filter = FALSE, size.filter = FALSE,
-  memoization = TRUE, check.package = TRUE, multi.core = TRUE) {
+  all.filters = FALSE, ip.filter = FALSE, small.filter = FALSE,
+  memoization = TRUE, check.package = TRUE, multi.core = TRUE,
+  dev.mode = FALSE, threshold = 1000L) {
 
   if (check.package) packages <- checkPackage(packages)
-  pkg.order <- packages
-
   ymd <- logDate(date)
   cran_log <- fetchCranLog(date = ymd, memoization = memoization)
   cran_log <- cleanLog(cran_log)
 
   cores <- multiCore(multi.core)
 
-  # N.B. using pkg_specific_filters not recommended!
   if (all.filters) {
     ip.filter <- TRUE
-    # triplet.filter <- TRUE
     small.filter <- TRUE
-    # sequence.filter <- TRUE
-    # size.filter <- TRUE
   }
 
-  pkg_specific_filters <- c(triplet.filter, sequence.filter, size.filter)
-
   if (ip.filter) {
-    row.delete <- ipFilter(cran_log, multi.core = cores)
-    cran_log <- cran_log[!row.names(cran_log) %in% row.delete, ]
+    cran_log <- ipFilter(cran_log, multi.core = cores, dev.mode = dev.mode)
   }
 
-  if (any(pkg_specific_filters)) {
-    pkgs <- unique(cran_log$package)
-
-    out <- parallel::mclapply(pkgs, function(p) {
-      cran_log[cran_log$package == p, ]
-    }, mc.cores = cores)
-
-    if (triplet.filter) {
-      out <- parallel::mclapply(out, tripletFilter, mc.cores = cores)
-    }
-
-    if (small.filter) {
-      out <- parallel::mclapply(out, smallFilter, mc.cores = cores)
-    }
-
-    if (sequence.filter) {
-      arch.pkg.history <- parallel::mclapply(pkgs, function(x) {
-        tmp <- packageHistory(x)
-        tmp[tmp$Date <= ymd & tmp$Repository == "Archive", ]
-      }, mc.cores = cores)
-
-      out <- parallel::mclapply(seq_along(out), function(i) {
-        sequenceFilter(out[[i]], arch.pkg.history[[i]])
-      }, mc.cores = cores)
-    }
-
-    if (size.filter) out <- sizeFilter(out, pkgs, cores)
-    cran_log <- do.call(rbind, out)
-
-  } else {
-    if (small.filter) cran_log <- smallFilter(cran_log)
-  }
+  if (small.filter) cran_log <- cran_log[cran_log$size >= threshold, ]
 
   freqtab <- sort(table(cran_log$package), decreasing = TRUE)
 
+  unobs.pkgs <- !packages %in% cran_log$package
+  if (any(unobs.pkgs)) pkg.msg <- paste(packages[unobs.pkgs], collapse = ", ")
+
+  if (all(unobs.pkgs)) {
+    stop("No downloads for ", pkg.msg, " on ", ymd, ".", call. = FALSE)
+  } else if (any(unobs.pkgs)) {
+    message("No downloads for ", pkg.msg, " on ", ymd, ".")
+    packages <- packages[!unobs.pkgs]
+  }
+
   # packages in bin
   pkg.bin <- lapply(packages, function(nm) {
     freqtab[freqtab %in% freqtab[nm]]
@@ -220,7 +189,7 @@ basePlot <- function(pkg, log_count, freqtab, iqr, package.data, y.max, date) {
     labels = paste("Tot = ", format(sum(freqtab), big.mark = ",")), cex = 0.8,
     col = "dodgerblue", pos = 2)
 
-  if (class(date) == "Date" ) {
+  if (inherits(date, "Date")) {
     day <- weekdays(as.Date(date), abbreviate = TRUE)
     title(main = paste0(pkg, " @ ", date, " (", day, ")"))
   } else {
@@ -242,7 +211,7 @@ ggPlot <- function(x, log_count, freqtab, iqr, package.data, y.max, date) {
   package.data <- x$package.data
   packages <- x$packages
 
-  if (class(date) == "Date") {
+  if (inherits(date, "Date")) {
     day <- weekdays(as.Date(date), abbreviate = TRUE)
     id <- paste0(package.data$packages, " @ ", date, " (", day, ")")
   } else {
